@@ -17,6 +17,7 @@ class LorisApp(Flask):
         self.config['schemata'] = list(config['schemata'].keys())
         self.config['tables'], self.config['autotables'] = \
             config.tables_to_list()
+        config.reload_users_dataframe()
 
 
 app = LorisApp(__name__)
@@ -26,6 +27,7 @@ app.config['external_wiki'] = config['external_wiki']
 
 mysql = MySQL(app)
 login_manager = LoginManager(app)
+login_manager.init_app(app)
 
 
 @login_manager.user_loader
